Moving Targets
========================

.. toctree::
   :maxdepth: 4

   source/moving_targets.callbacks
   source/moving_targets.learners
   source/moving_targets.masters
   source/moving_targets.metrics
   source/moving_targets.macs
